[Bf-blender-cvs] [65fb2ebb3c2] blender2.8: Merge branch 'master' into blender2.8

Campbell Barton noreply at git.blender.org
Thu Sep 20 03:38:37 CEST 2018


Commit: 65fb2ebb3c23432e16464db9246d292773d639b5
Author: Campbell Barton
Date:   Thu Sep 20 11:51:01 2018 +1000
Branches: blender2.8
https://developer.blender.org/rB65fb2ebb3c23432e16464db9246d292773d639b5

Merge branch 'master' into blender2.8

===================================================================



===================================================================

diff --cc source/blender/editors/space_view3d/view3d_project.c
index ec5f28b56f3,63057e01f20..0885d0e84c4
--- a/source/blender/editors/space_view3d/view3d_project.c
+++ b/source/blender/editors/space_view3d/view3d_project.c
@@@ -367,20 -367,19 +367,20 @@@ bool ED_view3d_clip_segment(const Regio
   * \param r_ray_co The world-space point where the ray intersects the window plane.
   * \param r_ray_normal The normalized world-space direction of towards mval.
   * \param r_ray_start The world-space starting point of the ray.
   * \param do_clip Optionally clip the start of the ray by the view clipping planes.
   * \return success, false if the ray is totally clipped.
   */
 -bool ED_view3d_win_to_ray_clipped_ex(
 +bool ED_view3d_win_to_ray_ex(
 +        struct Depsgraph *depsgraph,
          const ARegion *ar, const View3D *v3d, const float mval[2],
-         float r_ray_co[3], float r_ray_normal[3], float r_ray_start[3], bool do_clip)
+         float r_ray_co[3], float r_ray_normal[3], float r_ray_start[3], bool do_clip_planes)
  {
  	float ray_end[3];
  
 -	view3d_win_to_ray_segment(ar, v3d, mval, r_ray_co, r_ray_normal, r_ray_start, ray_end);
 +	view3d_win_to_ray_segment(depsgraph, ar, v3d, mval, r_ray_co, r_ray_normal, r_ray_start, ray_end);
  
  	/* bounds clipping */
- 	if (do_clip) {
+ 	if (do_clip_planes) {
  		return ED_view3d_clip_segment(ar->regiondata, r_ray_start, ray_end);
  	}
  
@@@ -397,15 -396,14 +397,15 @@@
   * \param mval The area relative 2d location (such as event->mval, converted into float[2]).
   * \param r_ray_start The world-space point where the ray intersects the window plane.
   * \param r_ray_normal The normalized world-space direction of towards mval.
   * \param do_clip Optionally clip the start of the ray by the view clipping planes.
   * \return success, false if the ray is totally clipped.
   */
 -bool ED_view3d_win_to_ray_clipped(
 +bool ED_view3d_win_to_ray(
 +        struct Depsgraph *depsgraph,
          const ARegion *ar, const View3D *v3d, const float mval[2],
-         float r_ray_start[3], float r_ray_normal[3], const bool do_clip)
+         float r_ray_start[3], float r_ray_normal[3], const bool do_clip_planes)
  {
- 	return ED_view3d_win_to_ray_ex(depsgraph, ar, v3d, mval, NULL, r_ray_normal, r_ray_start, do_clip);
 -	return ED_view3d_win_to_ray_clipped_ex(ar, v3d, mval, NULL, r_ray_normal, r_ray_start, do_clip_planes);
++	return ED_view3d_win_to_ray_ex(depsgraph, ar, v3d, mval, NULL, r_ray_normal, r_ray_start, do_clip_planes);
  }
  
  /**
@@@ -657,17 -655,17 +657,17 @@@ void ED_view3d_win_to_vector(const AReg
   * \param mval The area relative 2d location (such as event->mval, converted into float[2]).
   * \param r_ray_start The world-space starting point of the segment.
   * \param r_ray_end The world-space end point of the segment.
   * \param do_clip Optionally clip the ray by the view clipping planes.
   * \return success, false if the segment is totally clipped.
   */
 -bool ED_view3d_win_to_segment_clipped(
 -        const ARegion *ar, View3D *v3d, const float mval[2],
 -        float r_ray_start[3], float r_ray_end[3], const bool do_clip_planes)
 +bool ED_view3d_win_to_segment(struct Depsgraph *depsgraph,
 +                              const ARegion *ar, View3D *v3d, const float mval[2],
-                               float r_ray_start[3], float r_ray_end[3], const bool do_clip)
++                              float r_ray_start[3], float r_ray_end[3], const bool do_clip_planes)
  {
 -	view3d_win_to_ray_segment(ar, v3d, mval, NULL, NULL, r_ray_start, r_ray_end);
 +	view3d_win_to_ray_segment(depsgraph, ar, v3d, mval, NULL, NULL, r_ray_start, r_ray_end);
  
  	/* bounds clipping */
- 	if (do_clip) {
+ 	if (do_clip_planes) {
  		return ED_view3d_clip_segment((RegionView3D *)ar->regiondata, r_ray_start, r_ray_end);
  	}
@@@ -367,20 -367,19 +367,20 @@@ bool ED_view3d_clip_segment(const Regio
   * \param r_ray_normal The normalized world-space direction of towards mval.
   * \param r_ray_start The world-space starting point of the ray.
-  * \param do_clip Optionally clip the start of the ray by the view clipping planes.
+  * \param do_clip_planes Optionally clip the start of the ray by the view clipping planes.
   * \return success, false if the ray is totally clipped.
   */
@@@ -397,15 -396,14 +397,15 @@@
   * \param r_ray_start The world-space point where the ray intersects the window plane.
   * \param r_ray_normal The normalized world-space direction of towards mval.
-  * \param do_clip Optionally clip the start of the ray by the view clipping planes.
+  * \param do_clip_planes Optionally clip the start of the ray by the view clipping planes.
   * \return success, false if the ray is totally clipped.
   */
@@@ -657,17 -655,17 +657,17 @@@ void ED_view3d_win_to_vector(const AReg
   * \param r_ray_start The world-space starting point of the segment.
   * \param r_ray_end The world-space end point of the segment.
-  * \param do_clip Optionally clip the ray by the view clipping planes.
+  * \param do_clip_planes Optionally clip the ray by the view clipping planes.
   * \return success, false if the segment is totally clipped.
   */



More information about the Bf-blender-cvs mailing list